package com.widget.imagevideobanner.view;

import android.content.Context;
import android.os.Handler;
import android.support.annotation.Nullable;
import android.support.v7.widget.AppCompatImageView;
import android.util.Log;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.engine.GlideException;
import com.bumptech.glide.request.RequestListener;
import com.bumptech.glide.request.target.Target;
import com.widget.imagevideobanner.R;
import com.widget.imagevideobanner.bean.MediaBean;
import com.widget.imagevideobanner.player.IPlayTarget;
import com.widget.imagevideobanner.utils.ThrowableUtils;

/**
 * 5秒自动切换图片
 */
public class VpImageView extends AppCompatImageView implements IPlayTarget {

    private static final String TAG = "VpImageView";
    private static final int DEFAULT_SWITCH_PAGE_TIME = 5000;

    private OnActionFinishListener onPageChangedListener;

    private Handler handler = new Handler();
    private Runnable pageChangeRunable = new Runnable() {
        @Override
        public void run() {
            inActive();
            if (null != onPageChangedListener){
                onPageChangedListener.next();
            }
        }
    };

    private RequestListener requestListener = new RequestListener() {
        @Override
        public boolean onLoadFailed(@Nullable GlideException e, Object model, Target target, boolean isFirstResource) {
            Log.e(TAG,ThrowableUtils.getFullStackTrace(e));
            return false;
        }

        @Override
        public boolean onResourceReady(Object resource, Object model, Target target, DataSource dataSource, boolean isFirstResource) {
            return false;
        }
    };

    public VpImageView(Context context) {
        super(context);
    }

    public VpImageView(Context context, final MediaBean mediaBean, final OnActionFinishListener onPageChangedListener) {
        super(context);
        this.onPageChangedListener = onPageChangedListener;
        setImageUrl(mediaBean.getUrl());
    }

    private void setImageUrl(String url) {
        Log.e(TAG,url);
        Glide.with(getContext()).load(url)
                .error(R.drawable.load_fail)
                .placeholder(R.drawable.load_fail)
                .listener(requestListener).into(this);
    }

    @Override
    public void onActive() {
        handler.removeCallbacks(pageChangeRunable);
        handler.postDelayed(pageChangeRunable, DEFAULT_SWITCH_PAGE_TIME);
    }

    @Override
    public void inActive() {
        handler.removeCallbacks(pageChangeRunable);
    }

}
